@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Meta;
 {
-  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.11';
+  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.12';
 }
 
 use Moose;
@@ -37,7 +37,7 @@ Dist::Zilla::Plugin::GitHub::Meta - Add GitHub repo info to META.{yml,json}
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -117,8 +117,14 @@ sub metadata {
 	my $url		= $self -> api."/repos/show/$login/$repo_name";
 	my $response	= $http -> request('GET', $url);
 
+	if ($response -> {'success'} eq '') {
+		$self -> log("Err: Can't connect to GitHub.com");
+		return;
+	}
+
 	if ($response -> {'status'} == 401) {
 		$self -> log("Err: Not authorized");
+		return;
 	}
 
 	my $json_text = decode_json $response -> {'content'};
